.. -*- mode: rst -*-

People
------

This work is made available by a community of people, amongst which
the `INRIA Parietal Project Team <https://team.inria.fr/parietal/>`_
and the `scikit-learn <http://scikit-learn.org/>`_ folks, in
particular:

* Alexandre Abraham
* `Alexandre Gramfort <http://alexandre.gramfort.net>`_
* Vincent Michel
* Bertrand Thirion
* `Fabian Pedregosa <http://fa.bianp.net/>`_
* `Gael Varoquaux <http://gael-varoquaux.info/>`_
* Philippe Gervais
* Michael Eickenberg
* Danilo Bzdok
* Loïc Estève
* Kamalakar Reddy Daddy
* Elvis Dohmatob
* Alexandre Abadie
* Andres Hoyos Idrobo
* Salma Bougacha
* Mehdi Rahim

Many of also contributed outside of Parietal, notably:

* `Chris Filo Gorgolewski <http://multiplecomparisons.blogspot.fr/>`_
* `Ben Cipollini <http://cseweb.ucsd.edu/~bcipolli/>`_
* Julia Huntenburg
* Martin Perez-Guevara

Thanks to M. Hanke and Y. Halchenko for data and packaging.

Funding
........

Alexandre Abraham, Gael Varoquaux, Kamalakar Reddy Daddy, Loïc Estève,
Mehdi Rahim, Philippe Gervais where payed by the `NiConnect
<https://team.inria.fr/parietal/18-2/spatial_patterns/niconnect>`_
project, funded by the French `Investissement d'Avenir
<http://www.gouvernement.fr/investissements-d-avenir-cgi>`_.

.. _citing:

Citing nilearn
------------------------

There is no paper published yet about nilearn. We are waiting for the
package to mature a bit. However, the patterns underlying the package
have been described in: `Machine learning for neuroimaging with
scikit-learn
<http://journal.frontiersin.org/article/10.3389/fninf.2014.00014/abstract>`_.

We suggest that you read and cite the paper. Thank you.


Citing scikit-learn
------------------------

A huge amount of work goes in the scikit-learn. Researchers that invest
their time in developing and maintaining the package deserve recognition
with citations. In addition, the Parietal team needs the citations to the
paper in order to justify paying a software engineer on the project. To
guarantee the future of the toolkit, if you use it, please cite it.

See the scikit-learn documentation on `how to cite
<http://scikit-learn.org/stable/about.html#citing-scikit-learn>`_.

